@@ -169,10 +169,18 @@ class ResearchRecord(object):
         :return:
         """
         res = []
+        sql = "select count(*) from `" + self.db_database + "`.`" + self.db_table + "` WHERE `delete_flag` = " + \
+              "{}".format(str(delete_flag))
+        sum_page = None
+        if self._execute(sql):
+            sum_page = self.cursor.fetchone()[0]
+            sum_page = int(sum_page / page) + 1
+        else:
+            sum_page = 0
         sql = "select * from `" + self.db_database + "`.`" + self.db_table + "` WHERE `delete_flag` = " + \
               "{}".format(str(delete_flag)) + " LIMIT {} OFFSET {}".format(str(page), str(page_no * page))
         if self._execute(sql):
-            return self.cursor.fetchall()
+            return self.cursor.fetchall(), sum_page
         else:
             return []
 
@@ -283,7 +291,8 @@ class ResearchRecord(object):
                 if t == int or t == float:
                     condition_clause = condition_clause + str(kv[0][0]) + " " + str(kv[1]) + " " + str(kv[0][1])
                 elif t == tuple:
-                    condition_clause = condition_clause + str(kv[0][0]) + " " + str(kv[1]) + " " + str(kv[0][1])
+                    tuple_str = str(kv[0][1]) if len(kv[0][1]) > 1 else str(kv[0][1]).replace(",", "")
+                    condition_clause = condition_clause + str(kv[0][0]) + " " + str(kv[1]) + " " + tuple_str
                 elif t == str:
                     condition_clause = condition_clause + \
                                        str(kv[0][0]) + " " + str(kv[1]) + " " + "\"" + str(kv[0][1]) + "\""
@@ -393,28 +402,3 @@ class ResearchRecord(object):
 
 if __name__ == "__main__":
     basic_config(logs_style=LOG_STYLE_PRINT)
-    import ast
-    c = '{"db_url":"47.94.21.180","db_username":"root","pass":"Q7NRPeJao7GkOium","port":3306,"ssl_ip":"47.94.21.180","ssl_admin":"root","ssl_pwd":"liwudi1998328.","ssl_db_port":3306,"ssl_port":22,"ignore_error":True}'
-    c = ast.literal_eval(c)
-    a = ResearchRecord(**c)
-    def p(i) -> List:
-        if len(i[4]) == 0 or len(i[5]) == 0:
-            return []
-        strs = ", c=\'{\"db_url\":\"47.94.21.180\",\"db_username\":\"root\",\"pass\":\"Q7NRPeJao7GkOium\",\"port\":3306,\"ssl_ip\":\"47.94.21.180\",\"ssl_admin\":\"root\",\"ssl_pwd\":\"liwudi1998328.\",\"ssl_db_port\":3306,\"ssl_port\":22,\"ignore_error\":True}\'"
-        i[7] = i[4].replace("Best test rmse", "").replace("mae ", "").split(",")[0]
-        i[8] = i[4].replace("Best test rmse", "").replace("mae ", "").split(",")[1]
-        p = i[5].replace(strs, "").replace("Namespace(", "{").replace(")", "}").replace("{", "{\"").replace("=",                                                                                           "\"=").replace(
-            ", ", ", \"")
-        p = p.replace("{", "").replace("}", "")
-        k = p.split(", ")
-        m = {}
-        for q in k:
-            m[q.split("=")[0].replace("\"", "")] = q.split("=")[1]
-        i[9] = ""
-        for q in ["data_amount", "dataname", "datatype"]:
-            i[9] = i[9] + ", " + str(m[q])
-        i[10] = m["topk_m"]
-        i[6] = m["scity"]
-        return i
-    a.delete(ids=(818, 822))
-    a.export(id_range=(818, 822), file_type="xls", process=p)
